**Example 1: 获取所有资源数量**

获取所有资源数量

Input: 

```
tccli cwp DescribeAssetTotalCount --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "058e4d84-10de-4943-8b30-2a50f204f7c7",
        "Types": [
            {
                "Desc": "",
                "Key": "system",
                "NewCount": 0,
                "Value": 531
            },
            {
                "Desc": "",
                "Key": "account",
                "NewCount": 0,
                "Value": 6526360
            },
            {
                "Desc": "",
                "Key": "port",
                "NewCount": 0,
                "Value": 2355
            },
            {
                "Desc": "",
                "Key": "app",
                "NewCount": 8,
                "Value": 3193
            },
            {
                "Desc": "",
                "Key": "process",
                "NewCount": 21,
                "Value": 21749346
            },
            {
                "Desc": "",
                "Key": "database",
                "NewCount": 1,
                "Value": 18
            },
            {
                "Desc": "",
                "Key": "webapp",
                "NewCount": 0,
                "Value": 4
            },
            {
                "Desc": "",
                "Key": "webservice",
                "NewCount": 0,
                "Value": 17
            },
            {
                "Desc": "",
                "Key": "webframe",
                "NewCount": 0,
                "Value": 5
            },
            {
                "Desc": "",
                "Key": "weblocation",
                "NewCount": 0,
                "Value": 11
            },
            {
                "Desc": "",
                "Key": "jar",
                "NewCount": 0,
                "Value": 1086
            },
            {
                "Desc": "",
                "Key": "initservice",
                "NewCount": 0,
                "Value": 1922
            },
            {
                "Desc": "",
                "Key": "plantask",
                "NewCount": 0,
                "Value": 2950
            },
            {
                "Desc": "",
                "Key": "env",
                "NewCount": 0,
                "Value": 5914763
            },
            {
                "Desc": "",
                "Key": "coremodule",
                "NewCount": 0,
                "Value": 22143622
            },
            {
                "Desc": "",
                "Key": "package",
                "NewCount": 0,
                "Value": 310039
            }
        ]
    }
}
```

